@@ -61,6 +61,10 @@ def get_tool_list() -> List[BMTool]:
     spherical_prior_tool = SphericalPrior()
     tools.append(spherical_prior_tool)
 
+    from cryoloBM_tools.coords2cbox import Coords2CBOX
+    coords2cbox_tool = Coords2CBOX()
+    tools.append(coords2cbox_tool)
+
 
     return tools
 
