@@ -1,5 +1,7 @@
 """
 The following functions manage the changes due to the modifications of the values of the table tracing
+
+Which table?
 """
 
 from cryoloBM import constants,  helper, visualization_3D_Window
@@ -326,7 +328,7 @@ def display_preview(controller:boxmanager_controller, only_reload:bool)->None:
         img = controller.model.current_tomoimage_mmap[controller.model.index_tomo, :, :]
         controller.view.preview_win.display_img(controller.get_current_filename(with_extension=True), img, controller.model.index_tomo)
 
-def preview_run(controller, only_reload = False)->None:
+def preview_run(controller: boxmanager_controller, only_reload: bool = False)->None:
     """
     This function will collect the params, run the tracing and show the result
     :param controller: Boxmanager_controller obj
@@ -359,7 +361,7 @@ def preview_run(controller, only_reload = False)->None:
     display_preview(controller=controller, only_reload=only_reload)
 
 
-def get_patches(controller:boxmanager_controller)->List[MySketch.MySketch]:
+def get_patches(controller: boxmanager_controller) -> List[MySketch.MySketch]:
     """
     :param controller: Boxmanager_controller obj
     """
