@@ -1,6 +1,7 @@
 """
-All the functions used to load data from file
+The following functions manage the import data from file option
 """
+
 from cryoloBM import helper_filament, helper_image, constants, helper, MySketch,helper_GUI
 from cryolo import CoordsIO,utils
 
@@ -15,7 +16,7 @@ from typing import Union, List
 COLORS = ["b", "r", "c", "m", "y", "k", "w"]
 
 
-def box_to_sketch(controller:boxmanager_controller ,box:utils.BoundBox, color)->MySketch.MySketch:
+def box_to_sketch(controller: boxmanager_controller ,box: utils.BoundBox, color)->MySketch.MySketch:
     """
     Convert a bbox obj in a sketch. It is the old 'box_to_rectangle' function
     :param controller: Boxmanager_controller obj
@@ -112,6 +113,12 @@ def _check_correct_import_data(controller:boxmanager_controller, keep:bool, boxe
     return False
 
 def _load_data(controller:boxmanager_controller, pathfile:str, keep:bool, t_start:float)->List[Union[utils.Filament, utils.BoundBox]]:
+    """
+    :param controller: Boxmanager_controller obj
+    :param pathfile: path of the file from which to load data
+    :param keep: False if we want to discard the data
+    :param t_start: starting time
+    """
     boxes = list()
     controller.model.is_cbox = False
     if pathfile.endswith(".box"):
@@ -144,7 +151,7 @@ def _load_data(controller:boxmanager_controller, pathfile:str, keep:bool, t_star
 def _collect_filament(controller:boxmanager_controller, filaments:List[utils.Filament], dict_entry_name:str, keep:bool)->int:
     """
     Collect the filament, set all the 'filaments'' variables and return the number of collected filaments
-    :param controller: controller
+    :param controller: Boxmanager_controller obj
     :param filaments: list of filaments
     :param dict_entry_name: filename  file filename in case of SPA, tomo filename in case of folder
     """
@@ -298,7 +305,7 @@ def import_SPA(controller:boxmanager_controller, box_dir:str, keep:bool)->bool:
         elif not controller.model.has_filament:
             sketches = [box_to_sketch(controller=controller,box=box, color=rand_color) for box in boxes]
             box_imported += len(sketches)
-            controller.model.box_dictionary.add_sketches(sketches=sketches, f=dict_entry_name, n=controller.model.index_tomo, id_fil=None)
+            controller.model.box_dictionary.add_sketches(sketches=sketches, f=dict_entry_name, n=controller.model.index_tomo, id_fil=None,colour=rand_color)
             # the 'boxsize_dictionary' and 'visualization_dictionary' ll be fill in real time
 
         updated_entries.append(dict_entry_name)
@@ -352,7 +359,7 @@ def import_tomo_folder(controller:boxmanager_controller, box_dir:str, keep:bool)
                    or f.endswith(".cbox")
            )
     ]
-
+    onlyfiles.sort()
     for index,f in enumerate(onlyfiles):
         if not import_single_tomo(controller=controller, path_3d_file=path.join(box_dir, path.splitext(f)[0]),index_file=index, keep=keep):
             return False
@@ -470,6 +477,9 @@ def import_single_tomo(controller:boxmanager_controller, path_3d_file:str, index
     return True
 
 def import_data(controller:boxmanager_controller)->None:
+    """
+    :param controller: Boxmanager_controller obj
+    """
     if not controller.model.box_dictionary or (controller.model.unsaved_changes and controller.view.qtmessage(
                                 msg="There are unsaved changes. Are you sure?", has_cancel=True) == controller.view.clicked_cancel()):
         return
