@@ -2,12 +2,11 @@ from argparse import ArgumentParser
 import argparse
 from cryoloBM.bmtool import BMTool
 from cryolo.utils import Filament, BoundBox
-from cryolo.CoordsIO import read_cbox_boxfile, write_cbox_file, write_coords_file
+from cryolo.CoordsIO import read_cbox_boxfile, write_cbox_file
 from dataclasses import dataclass
 from typing import Tuple, List, Dict
 import numpy as np
 import os
-import copy
 import glob
 import tqdm
 
@@ -28,9 +27,8 @@ class RotateCBOXCoords(BMTool):
         cbox_path = args.input
         meta_path = args.meta
         output_path= args.out
-        propagation = args.propagation
-        do_zsplit = args.nozsplit==False
         zfloat = args.zfloat
+        extr_boxsize = args.boxsize
 
         cbox_files = self.get_cbox_files_paths(cbox_path)
         rotation_data = self.get_rotation_data(meta_path)
@@ -40,21 +38,13 @@ class RotateCBOXCoords(BMTool):
             is_filament = isinstance(cbox_dat[0], Filament)
             if is_filament:
                 # filament path
-                rotated_dat= self.rotate_filaments(filaments=cbox_dat, meta=rotation_meta)
+                rotated_dat= self.rotate_filaments(filaments=cbox_dat, meta=rotation_meta,extraction_box_size=extr_boxsize)
 
-                if do_zsplit:
-                    rotated_dat_new = []
-                    for fil in rotated_dat:
-                        rotated_boxes = self.zsplit_filament_2(fil.boxes, propagation)
-                        for boxes in rotated_boxes:
-                            f = Filament(boxes)
-                            rotated_dat_new.append(f)
-                    rotated_dat = rotated_dat_new
 
 
             else:
                 # bounding box path
-                rotated_dat = self.rotate_boundingbox(boxes=cbox_dat, meta_path=rotation_meta)
+                rotated_dat = self.rotate_boundingbox(boxes=cbox_dat, meta_path=rotation_meta, extraction_box_size=extr_boxsize)
                 if not zfloat:
                     for box in rotated_dat:
                         box.z = int(round(box.z))
@@ -67,45 +57,6 @@ class RotateCBOXCoords(BMTool):
             write_cbox_file(path=out_file_pth, coordinates=rotated_dat)
 
 
-            coords_dat = None
-            if is_filament:
-                coords_dat = self.generate_coords_array_filaments(rotated_dat)
-            else:
-                coords_dat = self.generate_coords_array(rotated_dat)
-
-            out_coords = os.path.join(output_path, "COORDS/")
-            os.makedirs(out_coords, exist_ok=True)
-            out_file_pth = os.path.join(out_coords, filename + ".coords")
-            np.savetxt(out_file_pth, coords_dat[:,:3], fmt='%f')
-
-            out_coords = os.path.join(output_path, "COORDS_FID/")
-            os.makedirs(out_coords, exist_ok=True)
-            out_file_pth = os.path.join(out_coords, filename + ".coords")
-            np.savetxt(out_file_pth, coords_dat, fmt='%f')
-
-
-            #write_coords_file(path=out_file_pth, boxes=coords_dat)
-
-
-
-    def generate_coords_array_filaments(self, data: List[Filament]):
-        all_fil_coords = []
-        for i, fil in enumerate(data):
-            coords = self.generate_coords_array(fil.boxes)
-            id = np.array([i]*len(fil.boxes))
-            id = id.reshape((len(id),1))
-            coords_fid = np.append(coords, id, axis=1)
-            all_fil_coords.append(coords_fid)
-        return np.concatenate(all_fil_coords)
-
-    def generate_coords_array(self, data: List[BoundBox]):
-        coords_dat = np.empty(shape=(len(data), 3))
-        for i, box in enumerate(data):
-            coords_dat[i, 0] = box.x + box.w/2
-            coords_dat[i, 1] = box.y + box.h/2
-            coords_dat[i, 2] = box.z
-        return coords_dat
-
     @staticmethod
     def match_cbox_rotation_data(cbox_files: List[str], rotation_meta: List[RotationMeta]):
         pairs=[]
@@ -116,9 +67,15 @@ class RotateCBOXCoords(BMTool):
                     pairs.append((pth,meta))
         return pairs
 
+    @staticmethod
+    def remove_out_of_volume_coords(coords: np.array, vol_dim : np.array, box_size = 0) -> np.array:
+        mask = np.array([True]*coords.shape[0])
+        for i in range(len(vol_dim)):
+            mask_dim = np.logical_and(coords[:,i]>=box_size,coords[:,i] < (vol_dim[i] - box_size/2))
+            mask = np.logical_and(mask,mask_dim)
+        return coords[mask]
 
-
-    def create_parser(self, parentparser: ArgumentParser) -> ArgumentParser:
+    def create_parser(self, parentparser: argparse.ArgumentParser) -> ArgumentParser:
         parser_cbox_rotate = parentparser.add_parser(
             self.get_command_name(),
             help="Given coordinates of from a rotated tomogram it rotates them back to a unrotated tomogram.",
@@ -126,7 +83,7 @@ class RotateCBOXCoords(BMTool):
         )
 
         req = parser_cbox_rotate.add_argument_group(
-            "Required arguments",
+            "Arguments",
             "Add filament prior information to star",
         )
 
@@ -144,14 +101,6 @@ class RotateCBOXCoords(BMTool):
             help="Path to meta file",
         )
 
-        req.add_argument(
-            "-p",
-            "--propagation",
-            default=2,
-            type=int,
-            help="Propagation factor for filament boxes. If a filament box is at position z after applying the rotation, the box is also added to slice z+-i with i in range of [-p,p]",
-        )
-
         req.add_argument(
             "-o",
             "--out",
@@ -159,16 +108,18 @@ class RotateCBOXCoords(BMTool):
             help="Path to output dir.",
         )
 
-        req.add_argument(
-            "--nozsplit",
-            default=False,
-            action="store_true",
-        )
-
         req.add_argument(
             "--zfloat",
             default=False,
             action="store_true",
+            help="If set, z is NOT converted to an integer"
+        )
+
+        req.add_argument(
+            "--boxsize",
+            default=-1,
+            type=int,
+            help="Extraction box size that should be taken into account when checking if rotated boxes are within the volume. If not provided, box size of CBOX files is used"
         )
 
         return parser_cbox_rotate
@@ -200,22 +151,32 @@ class RotateCBOXCoords(BMTool):
         files = glob.glob(os.path.join(pth,"*.cbox"))
         return files
 
-    def rotate_boundingbox(self, boxes : List[BoundBox], meta : RotationMeta) -> List[BoundBox]:
+    def rotate_boundingbox(self, boxes : List[BoundBox], meta : RotationMeta, extraction_box_size = -1) -> List[BoundBox]:
         '''
         Rotates the bounding boxes according rotation meta
         '''
 
         # create numpy array with x,y,z, apply necessary conversions
         coords = np.zeros(shape=(len(boxes),3))
-
+        avg_box_size = 0
         for i, b in enumerate(boxes):
             coords[i,0] = b.x + b.w/2
             coords[i,1] = b.y + b.h/2
             coords[i,2] = b.z
+            avg_box_size += b.w
+        avg_box_size = avg_box_size/len(boxes)
+        if extraction_box_size != -1:
+            avg_box_size = extraction_box_size
+
+
 
         rotated_boxes = []
 
         points = self.rotate_points(coords_raw=coords, meta=meta)
+
+        points = RotateCBOXCoords.remove_out_of_volume_coords(points, meta.dimension_rotated, box_size=avg_box_size)
+
+
         for row_index, row in enumerate(points):
             box = BoundBox(x=row[0]-boxes[row_index].w/2,
                            y=row[1]-boxes[row_index].h/2,
@@ -228,39 +189,9 @@ class RotateCBOXCoords(BMTool):
 
         return rotated_boxes
 
-    @staticmethod
-    def zsplit_filament_2(boxes: List[BoundBox], propagation: int) -> List[List[BoundBox]]:
-        '''
-        Splits filament into sub-filaments with constant z value
-        '''
-        def add_box_to_dict(box_dict: Dict, box: BoundBox, w:int=1):
-            for i in range(-w, (w+1)):
-                if (box.z+i) not in box_dict:
-                    box_dict[box.z+i] = []
-
-            for i in range(-w, (w + 1)):
-                b_cpy = copy.deepcopy(box)
-                b_cpy.z = b_cpy.z + i
-                box_dict[b_cpy.z].append(b_cpy)
-
-        splitted_filaments: List[Filament] = []
-        boxes_per_slice = {}
-
-        for b in boxes:
-            b = copy.deepcopy(b)
-            b.z = int(np.round(b.z))
-            add_box_to_dict(boxes_per_slice, b, propagation)
-        list_boxes = []
-        for key in boxes_per_slice:
-            list_boxes.append(boxes_per_slice[key])
-            #f = Filament(boxes=boxes_per_slice[key])
-            #splitted_filaments.append(f)
-
-        return list_boxes
-
-
     def rotate_filaments(self, filaments : List[Filament],
-                         meta : RotationMeta
+                         meta : RotationMeta,
+                         extraction_box_size : int = 0
                          ) -> List[Filament]:
         '''
         Rotates the filament positions.
@@ -270,7 +201,7 @@ class RotateCBOXCoords(BMTool):
 
         for filament in filaments:
             boxes = filament.boxes
-            rotated_boxes = [self.rotate_boundingbox(boxes=boxes,meta=meta)]
+            rotated_boxes = [self.rotate_boundingbox(boxes=boxes,meta=meta,extraction_box_size=extraction_box_size)]
             for boxes in rotated_boxes:
                 f = Filament(boxes=boxes)
                 rotated_filaments.append(f)
@@ -327,4 +258,6 @@ class RotateCBOXCoords(BMTool):
         )  # Half dimension orignal tomogram
         new_coords_recoords = np.add(new_coords, recoords_matrix_inv)
        # final = np.column_stack((new_coords_recoords))
+
+
         return new_coords_recoords
\ No newline at end of file
